Readme
======

.. image:: https://badge.fury.io/py/acdh-transkribus-utils.svg
    :target: https://badge.fury.io/py/acdh-transkribus-utils

A python package providing some utility functions for interacting with the [Transkribus-API](https://transkribus.eu/wiki/index.php/REST_Interface)


Installation
------------

    pip install acdh-transkribus-utils
